@@ -1,7 +1,7 @@
 static __attribute__((used)) char* rcsid = "$CVSHeader$";
 /*
  *
- * (c) 2004 Laurent Vivier <LaurentVivier@wanadoo.fr>
+ * (c) 2004 Laurent Vivier <Laurent@lvivier.info>
  *
  */
 
@@ -24,11 +24,11 @@ int emile_first_get_param(int fd, int *drive_num, int *second_offset,
 	if (ret != sizeof(firstBlock))
 		return EEMILE_CANNOT_READ_FIRST;
 
-	if ( strncmp( firstBlock.boot_block_header.SysName+1,
+	if ( strncmp( (char*)firstBlock.boot_block_header.SysName+1,
 		      "Mac Bootloader", 14) == 0 )
 	{
-		*drive_num = read_short(&firstBlock.second_param_block.ioVRefNum);
-		*second_offset = read_long(&firstBlock.second_param_block.ioPosOffset);
+		*drive_num = read_short((u_int16_t*)&firstBlock.second_param_block.ioVRefNum);
+		*second_offset = read_long((u_int32_t*)&firstBlock.second_param_block.ioPosOffset);
 		*second_size = read_long(&firstBlock.second_param_block.ioReqCount);
 	}
 	else
