@@ -1,7 +1,7 @@
 static __attribute__((used)) char* rcsid = "$CVSHeader$";
 /*
  *
- * (c) 2004 Laurent Vivier <LaurentVivier@wanadoo.fr>
+ * (c) 2004 Laurent Vivier <Laurent@lvivier.info>
  *
  */
 
@@ -29,15 +29,15 @@ int emile_first_set_param(int fd, unsigned short tune_mask, int drive_num,
 	if (ret != sizeof(firstBlock))
 		return EEMILE_CANNOT_READ_FIRST;
 
-	if ( strncmp( firstBlock.boot_block_header.SysName+1,
+	if ( strncmp( (char*)firstBlock.boot_block_header.SysName+1,
 		      "Mac Bootloader", 14) == 0 )
 	{
 		if (tune_mask & EMILE_FIRST_TUNE_DRIVE)
-			write_short(&firstBlock.second_param_block.ioVRefNum, 
+			write_short((u_int16_t*)&firstBlock.second_param_block.ioVRefNum, 
 				    drive_num);
 
 		if (tune_mask & EMILE_FIRST_TUNE_OFFSET)
-			write_long(&firstBlock.second_param_block.ioPosOffset, 
+			write_long((u_int32_t*)&firstBlock.second_param_block.ioPosOffset, 
 				   second_offset);
 
 		if (tune_mask & EMILE_FIRST_TUNE_SIZE)
