@@ -1,7 +1,7 @@
 static __attribute__((used)) char* rcsid = "$CVSHeader$";
 /*
  *
- * (c) 2004 Laurent Vivier <LaurentVivier@wanadoo.fr>
+ * (c) 2004 Laurent Vivier <Laurent@lvivier.info>
  *
  */
 
@@ -9,6 +9,7 @@ static __attribute__((used)) char* rcsid = "$CVSHeader$";
 
 #include "partition.h"
 #include "libemile.h"
+#include "emile.h"
 
 int emile_map_get_bootinfo(emile_map_t *map, int* bootstart, int *bootsize,
 		           int *bootaddr, int *bootentry, int* checksum,
@@ -17,11 +18,11 @@ int emile_map_get_bootinfo(emile_map_t *map, int* bootstart, int *bootsize,
 	 if (!emile_map_is_valid(map))
 		 return -1;
 
-	*bootstart = map->partition.LgBootStart;
-	*bootsize = map->partition.BootSize;
-	*bootaddr = map->partition.BootAddr;
-	*bootentry = map->partition.BootEntry;
-	*checksum = map->partition.BootCksum;
+	*bootstart = read_long((u_int32_t*)&map->partition.LgBootStart);
+	*bootsize = read_long((u_int32_t*)&map->partition.BootSize);
+	*bootaddr = read_long((u_int32_t*)&map->partition.BootAddr);
+	*bootentry = read_long((u_int32_t*)&map->partition.BootEntry);
+	*checksum = read_long((u_int32_t*)&map->partition.BootCksum);
 	strcpy(processor, map->partition.Processor);
 
 	return 0;
