@@ -1,17 +1,18 @@
 static __attribute__((used)) char* rcsid = "$CVSHeader$";
 /*
  *
- * (c) 2004 Laurent Vivier <LaurentVivier@wanadoo.fr>
+ * (c) 2004 Laurent Vivier <Laurent@lvivier.info>
  *
  */
 
 #include "partition.h"
 #include "libemile.h"
+#include "emile.h"
 
 int emile_map_get_driver_number(emile_map_t *map)
 {
 	if (!emile_map_is_valid(map))
 		return -1;
 
-	return map->drivers.DrvrCount;
+	return read_short((u_int16_t*)&map->drivers.DrvrCount);
 }
