@@ -1,7 +1,7 @@
 static __attribute__((used)) char* rcsid = "$CVSHeader$";
 /*
  *
- * (c) 2004 Laurent Vivier <LaurentVivier@wanadoo.fr>
+ * (c) 2004 Laurent Vivier <Laurent@lvivier.info>
  *
  */
 
@@ -10,8 +10,9 @@ static __attribute__((used)) char* rcsid = "$CVSHeader$";
 
 #include "partition.h"
 #include "libemile.h"
+#include "emile.h"
 
 int emile_map_get_number(emile_map_t *map)
 {
-	return map->partition.MapBlkCnt;
+	return read_long((u_int32_t*)&map->partition.MapBlkCnt);
 }
