@@ -1,7 +1,7 @@
 static __attribute__((used)) char* rcsid = "$CVSHeader$";
 /*
  *
- * (c) 2004 Laurent Vivier <LaurentVivier@wanadoo.fr>
+ * (c) 2004 Laurent Vivier <Laurent@lvivier.info>
  *
  */
 
@@ -35,7 +35,8 @@ emile_map_t* emile_map_open(char *dev, int flags)
 		free(map);
 		return NULL;
 	}
-	strncpy(map->name, dev, 16);
+	strncpy(map->name, dev, MAP_NAME_LEN);
+	map->name[MAP_NAME_LEN - 1] = 0;
 
 	ret = read(map->fd, &map->drivers, sizeof(map->drivers));
 	if (ret == -1)
