@@ -1,14 +1,15 @@
 static __attribute__((used)) char* rcsid = "$CVSHeader$";
 /*
  *
- * (c) 2004 Laurent Vivier <LaurentVivier@wanadoo.fr>
+ * (c) 2004 Laurent Vivier <Laurent@lvivier.info>
  *
  */
 
 #include "partition.h"
 #include "libemile.h"
+#include "emile.h"
 
 int emile_map_partition_get_flags(emile_map_t *map)
 {
-	return map->partition.PartStatus;
+	return read_long((u_int32_t*)&map->partition.PartStatus);
 }
