@@ -1,7 +1,7 @@
 static __attribute__((used)) char* rcsid = "$CVSHeader$";
 /*
  *
- * (c) 2004 Laurent Vivier <LaurentVivier@wanadoo.fr>
+ * (c) 2004 Laurent Vivier <Laurent@lvivier.info>
  *
  */
 
@@ -10,5 +10,6 @@ static __attribute__((used)) char* rcsid = "$CVSHeader$";
 
 int emile_map_partition_is_startup(emile_map_t *map)
 {
-	return (map->partition.PartStatus & kPartitionIsStartup) == kPartitionIsStartup;
+	return (emile_map_partition_get_flags(map)
+		& kPartitionIsStartup) == kPartitionIsStartup;
 }
