@@ -1,7 +1,7 @@
 static __attribute__((used)) char* rcsid = "$CVSHeader$";
 /*
  *
- * (c) 2004 Laurent Vivier <LaurentVivier@wanadoo.fr>
+ * (c) 2004 Laurent Vivier <Laurent@lvivier.info>
  *
  */
 
@@ -10,6 +10,7 @@ static __attribute__((used)) char* rcsid = "$CVSHeader$";
 
 #include "partition.h"
 #include "libemile.h"
+#include "emile.h"
 
 int emile_map_read(emile_map_t *map, int part)
 {
@@ -19,7 +20,7 @@ int emile_map_read(emile_map_t *map, int part)
 	if (map->current == part)
 		return part;
 
-	if (part > map->partition.MapBlkCnt)
+	if (part > read_long((u_int32_t*)&map->partition.MapBlkCnt))
 		return -1;
 
 	offset = part * sizeof(struct Partition) + sizeof(struct DriverDescriptor);
