@@ -1,12 +1,13 @@
 static __attribute__((used)) char* rcsid = "$CVSHeader$";
 /*
  *
- * (c) 2004 Laurent Vivier <LaurentVivier@wanadoo.fr>
+ * (c) 2004 Laurent Vivier <Laurent@lvivier.info>
  *
  */
 
 #include "partition.h"
 #include "libemile.h"
+#include "emile.h"
 
 int emile_map_set_driver_number(emile_map_t *map, int number)
 {
@@ -16,7 +17,7 @@ int emile_map_set_driver_number(emile_map_t *map, int number)
 	if (number >= DD_MAX_DRIVER)
 		return -1;
 
-	map->drivers.DrvrCount = number;
+	write_short((u_int16_t*)&map->drivers.DrvrCount, number);
 
 	return 0;
 }
