@@ -1,19 +1,14 @@
 static __attribute__((used)) char* rcsid = "$CVSHeader$";
 /*
  *
- * (c) 2004 Laurent Vivier <LaurentVivier@wanadoo.fr>
+ * (c) 2004 Laurent Vivier <Laurent@lvivier.info>
  *
  */
 
 #include "partition.h"
 #include "libemile.h"
 
-#define MAJOR_HD	3
-#define MAJOR_SD	8
-static char *scsi_base = "/dev/sd";
-static char *ide_base = "/dev/hd";
-
-int emile_scsi_get_rdev(char* dev_name, char** driver, int *disk, int *partition)
+int emile_scsi_get_rdev(char* dev_name, int* driver, int *disk, int *partition)
 {
 	int ret;
 	struct stat st;
@@ -27,18 +22,18 @@ int emile_scsi_get_rdev(char* dev_name, char** driver, int *disk, int *partition
 		/*  not a block device */
 		return -1;
 
-	major = (st.st_rdev >> 8) & 0x0F;
+	major = (st.st_rdev >> 8) & 0xFF;
+	*driver = major;
 	switch(major)
 	{
 	case MAJOR_SD:
-		*driver = scsi_base;
 		*disk = (st.st_rdev & 0xFF) >> 4;
-		*partition = st.st_rdev &  0x0F;
+		if (partition) *partition = st.st_rdev &  0x0F;
 		break;
-	case MAJOR_HD:
-		*driver = ide_base;
+	case MAJOR_IDE0:
+	case MAJOR_IDE1:
 		*disk = (st.st_rdev & 0xFF) >> 6;
-		*partition = st.st_rdev &  0x3F;
+		if (partition) *partition = st.st_rdev &  0x3F;
 		break;
 	default:
 		return -1;
