@@ -1,6 +1,6 @@
 /*
  *
- * (c) 2004,2005 Laurent Vivier <LaurentVivier@wanadoo.fr>
+ * (c) 2004,2005 Laurent Vivier <Laurent@lvivier.info>
  *
  */
 
@@ -19,7 +19,7 @@ OSErr SerGetBuf(short refNum, long *count)
 	
 	res = PBStatusSync((ParmBlkPtr)&param);
 
-	*count = *(long*)&param.csParam;
+	*count = *(long*)param.csParam;
 
 	return res;
 }
