@@ -1,6 +1,6 @@
 /*
  *
- * (c) 2004,2005 Laurent Vivier <LaurentVivier@wanadoo.fr>
+ * (c) 2004,2005 Laurent Vivier <Laurent@lvivier.info>
  *
  */
 
@@ -11,10 +11,12 @@
 
 typedef u_int32_t	KeyMap[4];
 
+#ifdef __mc68000__
 static inline void GetKeys(KeyMap theKeys)
 {
 	asm("move.l %0, -(%%sp)\n"
 		Trap(_GetKeys)
 	    :: "g" (theKeys) : "%%d0", UNPRESERVED_REGS );
 }
+#endif /* __mc68000__ */
 #endif /* __MACOS_EVENTS_H__ */
