@@ -1,20 +1,20 @@
 /*
  *
- * (c) 2004,2005 Laurent Vivier <LaurentVivier@wanadoo.fr>
+ * (c) 2004,2005 Laurent Vivier <Laurent@lvivier.info>
  *
  */
 
 #ifndef __MACOS_TYPES_H__
 #define __MACOS_TYPES_H__
 
-#ifdef ARCH_M68K
+#ifndef _SYS_TYPES_H
 typedef unsigned char u_int8_t;
 typedef signed char int8_t;
 typedef unsigned short u_int16_t;
 typedef signed short int16_t;
 typedef unsigned int u_int32_t;
 typedef signed int int32_t;
-#endif /* ARCH_M68K */
+#endif /* _SYS_TYPES_H */
 
 typedef int16_t OSErr;
 typedef unsigned long FourCharCode;
