@@ -1,6 +1,6 @@
 /*
  *
- * (c) 2004, 2005 Laurent Vivier <LaurentVivier@wanadoo.fr>
+ * (c) 2004, 2005 Laurent Vivier <Laurent@lvivier.info>
  *
  */
 
@@ -13,9 +13,9 @@
 
 #include "libscsi.h"
 
-int scsi_INQUIRY(int target, char *buffer, size_t count)
+int scsi_INQUIRY(int target, void *buffer, size_t count)
 {
-	char	cdb[6];
+	unsigned char	cdb[6];
 	TIB_t	tib[2];
 
 	cdb[0] = INQUIRY;
