@@ -1,6 +1,6 @@
 /*
  *
- * (c) 2004, 2005 Laurent Vivier <LaurentVivier@wanadoo.fr>
+ * (c) 2004, 2005 Laurent Vivier <Laurent@lvivier.info>
  *
  */
 
@@ -10,17 +10,46 @@
 
 #include <macos/types.h>
 #include <macos/errors.h>
+#include <macos/scsi.h>
+#include <macos/lowmem.h>
 
 #include "libscsi.h"
 
 #define COMPLETION_TIMEOUT	300
 
-int scsi_command(int target, char* cdb, int count, TIB_t* tib)
+#define SCSI_BUSY		(1 << 6)
+#define SCSI_SEL		(1 << 1)
+
+static inline int scsi_busy(void)
+{
+	return (SCSIStat() & (SCSI_BUSY | SCSI_SEL)) != 0;
+}
+
+static inline int scsi_wait_bus()
+{
+	int timeout;
+
+	timeout = Ticks + 300;
+
+	while (scsi_busy())
+		if (Ticks > timeout)
+			return scsiBusy;
+	return noErr;
+}
+
+int scsi_command(int target, unsigned char* cdb, int count, TIB_t* tib)
 {
 	int err;
 	short stat;
 	short message;
 
+	err = scsi_wait_bus();
+	if (err != noErr)
+	{
+		printf("SCSI bus is busy\n");
+		return err;
+	}
+
 	err = SCSIGet();
 	if (err != noErr) 
 	{
@@ -42,11 +71,14 @@ int scsi_command(int target, char* cdb, int count, TIB_t* tib)
 		goto complete;
 	}
 
-	err = SCSIRead(tib);
-	if (err != noErr) 
+	if (tib != NULL)
 	{
-		printf("Cannot read data (%d)\n", err);
-		goto complete;
+		err = SCSIRead(tib);
+		if ((err != scPhaseErr) && (err != noErr))
+		{
+			printf("Cannot read data (%d)\n", err);
+			goto complete;
+		}
 	}
 
 complete:
