@@ -1,6 +1,6 @@
 /*
  * 
- * (c) 2004 Laurent Vivier <LaurentVivier@wanadoo.fr>
+ * (c) 2004 Laurent Vivier <Laurent@lvivier.info>
  *
  */
 
@@ -21,8 +21,10 @@ console_init(emile_l2_header_t* info)
 {
 	if (read_config_vga(info->configuration) == 0)
 	{
-		vga_init();
-		vga_enabled = 1;
+		if (vga_init())
+			vga_enabled = 0;
+		else
+			vga_enabled = 1;
 	}
 	serial_init(info);
 }
