@@ -1,6 +1,6 @@
 /*
  *
- * (c) 2005 Laurent Vivier <LaurentVivier@wanadoo.fr>
+ * (c) 2005-2007 Laurent Vivier <Laurent@lvivier.info>
  *
  */
 
@@ -23,10 +23,6 @@ typedef void (*disable_cache_t) (void);
 #define PAGE_SIZE	(1UL << PAGE_SHIFT)
 #define PAGE_MASK	(~(PAGE_SIZE-1))
 
-#ifdef ARCH_PPC
-#include "enter_kernelPPC.h"
-#endif
-
 extern void enter_kernel_init(void);
 extern unsigned long enter_kernel;
 extern unsigned long end_enter_kernel;
