@@ -1,6 +1,6 @@
 /*
  *
- * (c) 2004 Laurent Vivier <LaurentVivier@wanadoo.fr>
+ * (c) 2004 Laurent Vivier <Laurent@lvivier.info>
  *
  */
 
@@ -24,7 +24,7 @@ unsigned char *c2pstring(char* s)
 }
 
 static char buffer[256];
-unsigned char *p2cstring(unsigned char* s)
+char *p2cstring(unsigned char* s)
 {
 
 	memcpy(buffer, s + 1, s[0]);
